@@ -1,5 +1,6 @@
-from asgiref.sync import sync_to_async, AsyncToSync
-from io import BytesIO, StringIO
+from io import BytesIO
+
+from asgiref.sync import AsyncToSync, sync_to_async
 
 
 class WsgiToAsgi:
@@ -65,14 +66,14 @@ class WsgiToAsgiInstance:
             environ["SERVER_NAME"] = "localhost"
             environ["SERVER_PORT"] = 80
         # Go through headers and make them into environ entries
-        for name, value in self.scope.get('headers', []):
+        for name, value in self.scope.get("headers", []):
             name = name.decode("latin1")
             if name == "content-length":
                 corrected_name = "CONTENT_LENGTH"
             elif name == "content-type":
                 corrected_name = "CONTENT_TYPE"
             else:
-                corrected_name = 'HTTP_%s' % name.upper().replace("-", "_")
+                corrected_name = "HTTP_%s" % name.upper().replace("-", "_")
             # HTTPbis say only ASCII chars are allowed in headers, but we latin1 just in case
             value = value.decode("latin1")
             if corrected_name in environ:
@@ -120,9 +121,9 @@ class WsgiToAsgiInstance:
                 self.response_started = True
                 self.sync_send(self.response_start)
             self.sync_send({
-                "type": "http.response.content",
-                "content": output,
-                "more_content": True,
+                "type": "http.response.body",
+                "body": output,
+                "more_body": True,
             })
         # Close connection
-        self.sync_send({"type": "http.response.content"})
+        self.sync_send({"type": "http.response.body"})
